from setuptools import setup

setup(name='teim_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['teim_distributions'],
      author = 'Nick Teim',
      auther_email = 'NickTeim@something.com',
      zip_safe=False)
